Learn R Programming

distreg.vis (version 1.7.1)

expl_vars: Internal: Function to obtain all explanatory variables used to fit a model, without the dependent variables

Description

Internal: Function to obtain all explanatory variables used to fit a model, without the dependent variables

Usage

expl_vars(model)

Arguments